@@ -13,9 +13,9 @@ use Text::Fold ();
 use constant DEBUG => $ENV{TLDR_DEBUG};
 use constant REPOSITORY => $ENV{TLDR_REPOSITORY};
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
-my $URL = "https://raw.github.com/tldr-pages/tldr/master/pages/%s/%s.md";
+my $URL = "https://raw.githubusercontent.com/tldr-pages/tldr/master/pages/%s/%s.md";
 
 sub new {
     my ($class, %option) = @_;
